@@ -75,16 +75,26 @@ def get_col_types(df, columns=None):
         print(f'{col}: {type(value)}: {value}')
 
 
-def dataset_summary(df):
+def dataset_summary(data, index_summary=True, detail=False, quick=True):
     import pandas as pd
+    if index_summary:
+        df = data.copy()
+        df = df.reset_index()
+    else:
+        df = data
     df_s = pd.DataFrame(df.dtypes, columns = ['type'])
-    df_s = df_s.merge(df.head(1).T, left_index=True, right_index=True, how = 'outer')
-    df_s = df_s.merge(df.tail(1).T, left_index=True, right_index=True, how = 'outer')
-    df_s = df_s.merge(pd.DataFrame(df.min(), columns = ['min']), left_index=True, right_index=True, how = 'outer')
-    df_s = df_s.merge(pd.DataFrame(df.max(), columns = ['max']), left_index=True, right_index=True, how = 'outer')
-    df_s = df_s.merge(pd.DataFrame(df.mean(numeric_only=None), columns = ['mean']), left_index=True, right_index=True, how = 'outer')
-    df_s = df_s.merge(pd.DataFrame(df.std(), columns = ['std']), left_index=True, right_index=True, how = 'outer')
+    if detail:
+        df_s = df_s.merge(df.head(1).T, left_index=True, right_index=True, how = 'outer')
+        df_s = df_s.merge(df.tail(1).T, left_index=True, right_index=True, how = 'outer')
+        df_s = df_s.merge(pd.DataFrame(df.min(), columns = ['min']), left_index=True, right_index=True, how = 'left')
+        df_s = df_s.merge(pd.DataFrame(df.max(), columns = ['max']), left_index=True, right_index=True, how = 'left')
+        df_s.columns = ['type', 'first', 'last', 'min', 'max']
+    if not quick:
+        df_s = df_s.merge(pd.DataFrame(df.mean(numeric_only=None), columns = ['mean']), left_index=True, right_index=True, how = 'outer')
+        df_s = df_s.merge(pd.DataFrame(df.std(), columns = ['std']), left_index=True, right_index=True, how = 'outer')
+    df_s = df_s.merge(pd.DataFrame(df.nunique(), columns = ['n_uniq']), left_index=True, right_index=True, how = 'outer')
     df_s = df_s.merge(pd.DataFrame(df.isnull().sum(), columns = ['n_miss']), left_index=True, right_index=True, how = 'outer')
+    df_s = df_s.merge(pd.DataFrame(df.count(), columns = ['obs']), left_index=True, right_index=True, how = 'outer')
     return df_s
 
 
@@ -162,15 +172,20 @@ def load_bzipped(data:object):
     return pickle.loads(bz2.decompress(data))
 
 
-def read_batched_shops_data(conn:object, batch:list, table_schema:str, table_name:str):
-    shops = ','.join(batch.astype(str)) 
-    return conn.get(
-        f"""
-        SELECT *
-        FROM {table_schema}.{table_name}
-        WHERE shop_id in ({shops});
-        """
-    )
+def read_batched_shops_data(conn:object, batch:list, table_schema:str, table_name:str, run_id_col:str=None, run_id:str=None):
+    shops = ','.join(batch.astype(str))
+    if run_id_col != None:
+        tbl = conn.get(f"""SELECT *
+                           FROM {table_name}
+                           WHERE {run_id_col} = '{run_id}'
+                           AND shop_id in ({shops});
+                        """, optimize_verbose=False, timing_verbose=False)        
+    else:    
+        tbl = conn.get(f"""SELECT *
+                           FROM {table_name}
+                           WHERE shop_id in ({shops});
+                        """, optimize_verbose=False, timing_verbose=False)
+    return tbl
 
 
 def preprocess_activities(shop_data:pd.DataFrame, activities_column:str='occasion_type_id', prefix:str='event_'):
